"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildFunctions = exports.getOutFileForLambda = exports.getOutDirForLambda = void 0;
const esbuild_1 = require("esbuild");
const generateFunctionName_1 = require("./generate/generateFunctionName");
const utils_sh_1 = require("@goldstack/utils-sh");
const getOutDirForLambda = (config) => {
    if (config.path === '$default') {
        return `./distLambda/${config.path}`;
    }
    if (config.path.endsWith('/')) {
        return `./distLambda${config.path}index`;
    }
    return `./distLambda${config.path}`;
};
exports.getOutDirForLambda = getOutDirForLambda;
const getOutFileForLambda = (config) => {
    return `${(0, exports.getOutDirForLambda)(config)}/lambda.js`;
};
exports.getOutFileForLambda = getOutFileForLambda;
const buildFunctions = async ({ routesDir, configs, deploymentName, buildOptions, lambdaNamePrefix, routeFilter, }) => {
    const buildConfig = (0, utils_sh_1.readToType)('./esbuild.config.json');
    // if we have a filter, we don't remove previous outputs
    if (!routeFilter) {
        await (0, utils_sh_1.rmSafe)('./distLambda');
        (0, utils_sh_1.mkdir)('-p', './distLambda/zips');
    }
    for await (const config of configs) {
        (0, utils_sh_1.mkdir)('-p', (0, exports.getOutDirForLambda)(config));
        const esbuildLocalPath = (0, utils_sh_1.changeExtension)(`${routesDir}/${config.relativeFilePath}`, '.esbuild.config.json');
        const functionName = (0, generateFunctionName_1.generateFunctionName)(lambdaNamePrefix, config);
        const localBuildConfig = (0, utils_sh_1.readToType)(esbuildLocalPath);
        const onCSSGenerated = (css) => {
            generatedCss.push(css);
        };
        const generatedCss = [];
        const res = await (0, esbuild_1.build)({
            ...buildOptions({ onCSSGenerated, deploymentName }),
            entryPoints: [`${routesDir}/${config.relativeFilePath}`],
            outfile: (0, exports.getOutFileForLambda)(config),
            ...buildConfig,
            ...localBuildConfig,
        });
        if (res.metafile) {
            (0, utils_sh_1.write)(JSON.stringify(res.metafile), `./distLambda/zips/${functionName}.meta.json`);
        }
        // provide CSS for initial load
        (0, utils_sh_1.write)(generatedCss.join('\n'), `${(0, exports.getOutDirForLambda)(config)}/client.bundle.css`);
    }
};
exports.buildFunctions = buildFunctions;
//# sourceMappingURL=buildFunctions.js.map